pub struct ParsedQuery(/* private fields */);Trait Implementations
Sourceimpl Clone for ParsedQuery
impl Clone for ParsedQuery
Sourcefn clone(&self) -> ParsedQuery
fn clone(&self) -> ParsedQuery
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParsedQuery
impl Debug for ParsedQuery
Sourceimpl Display for ParsedQuery
impl Display for ParsedQuery
Sourceimpl<'a> TryInto<ParsedQuery> for &'a String
impl<'a> TryInto<ParsedQuery> for &'a String
Sourcetype Error = KlickhouseError
type Error = KlickhouseError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<ParsedQuery>
fn try_into(self) -> Result<ParsedQuery>
Performs the conversion.
Sourceimpl<'a> TryInto<ParsedQuery> for &'a str
impl<'a> TryInto<ParsedQuery> for &'a str
Sourcetype Error = KlickhouseError
type Error = KlickhouseError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<ParsedQuery>
fn try_into(self) -> Result<ParsedQuery>
Performs the conversion.
Sourceimpl<'a> TryInto<ParsedQuery> for QueryBuilder<'a>
impl<'a> TryInto<ParsedQuery> for QueryBuilder<'a>
Sourcetype Error = KlickhouseError
type Error = KlickhouseError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<ParsedQuery>
fn try_into(self) -> Result<ParsedQuery>
Performs the conversion.
Sourceimpl TryInto<ParsedQuery> for SelectBuilder
impl TryInto<ParsedQuery> for SelectBuilder
Sourcetype Error = KlickhouseError
type Error = KlickhouseError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<ParsedQuery>
fn try_into(self) -> Result<ParsedQuery>
Performs the conversion.
Sourceimpl TryInto<ParsedQuery> for String
impl TryInto<ParsedQuery> for String
Sourcetype Error = KlickhouseError
type Error = KlickhouseError
The type returned in the event of a conversion error.
Sourcefn try_into(self) -> Result<ParsedQuery>
fn try_into(self) -> Result<ParsedQuery>
Performs the conversion.